#PROG: objcopy
#as: --32
#objcopy:
#readelf: -n

Displaying notes found in: .note.gnu.property
  Owner                 Data size	Description
  GNU                  0x00000008	NT_GNU_PROPERTY_TYPE_0
      Properties: no copy on protected 
