#source: pr19636-3.s
#as: --32
#ld: -pie -m elf_i386
#readelf : -r --dyn-syms --wide

There are no relocations in this file.

Symbol table '\.dynsym' contains 1 entries:
 +Num: +Value +Size Type +Bind +Vis +Ndx Name
 +0: 0+ +0 +NOTYPE +LOCAL +DEFAULT +UND +
